#[repr(transparent)]pub struct Subsec(pub u32);Expand description
RTC Sub-second Counter register
Tuple Fields
0: u32Implementations
Sourceimpl Subsec
impl Subsec
Sourcepub const fn rtc_subsec(&self) -> u16
pub const fn rtc_subsec(&self) -> u16
A read reflects the current value of the 32Khz sub-second counter. This counter will be cleared whenever the SUBSEC_ENA bit in the RTC_CONTROL register is low. Up-counting at a 32 KHz rate commences at the start of the next one-second interval after the SUBSEC_ENA bit is set. This counter must be re-enabled after exiting deep_powerdown mode or after the main RTC module has been disabled and re-enabled. On modules not equipped with a sub-second counter, this register will read-back as all zeroes.
Sourcepub const fn set_rtc_subsec(&mut self, val: u16)
pub const fn set_rtc_subsec(&mut self, val: u16)
A read reflects the current value of the 32Khz sub-second counter. This counter will be cleared whenever the SUBSEC_ENA bit in the RTC_CONTROL register is low. Up-counting at a 32 KHz rate commences at the start of the next one-second interval after the SUBSEC_ENA bit is set. This counter must be re-enabled after exiting deep_powerdown mode or after the main RTC module has been disabled and re-enabled. On modules not equipped with a sub-second counter, this register will read-back as all zeroes.