nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Wake

Struct Wake 

#[repr(transparent)]
pub struct Wake(pub u32);
High-resolution/wake-up timer control register

Tuple Fields

0: u32

Implementations

Source

impl Wake

pub const fn val(&self) -> u16

A read reflects the current value of the high-resolution/wake-up timer. A write pre-loads a start count value into the wake-up timer and initializes a count-down sequence. Do not write to this register while counting is in progress.

pub const fn set_val(&mut self, val: u16)

A read reflects the current value of the high-resolution/wake-up timer. A write pre-loads a start count value into the wake-up timer and initializes a count-down sequence. Do not write to this register while counting is in progress.